@@ -203,15 +203,15 @@ local GetScoresRequestProcessor = function(res, params)
 			if data and data[playerStr] then
 				if foundLeaderboard then
 					if SL["P"..i].ActiveModifiers.ShowEXScore then
-						loadingText:settext("EX Score")
+						loadingText:settext(THEME:GetString("Groovestats", "EXScore"))
 					else
-						loadingText:settext("GrooveStats")
+						loadingText:settext(THEME:GetString("Groovestats", "GrooveStats"))
 					end
 				else
 					if SL["P"..i].ActiveModifiers.ShowEXScore then
-						loadingText:settext("No EX Data")
+						loadingText:settext(THEME:GetString("Groovestats", "NoEXData"))
 					else
-						loadingText:settext("No Data")
+						loadingText:settext(THEME:GetString("Groovestats", "NoData"))
 					end
 				end
 			else
@@ -279,7 +279,7 @@ af[#af+1] = RequestResponseActor(17, 50)..{
 				-- If we disable the service from a previous request, surface it to the user here.
 				for i=1,2 do
 					local loadingText = master:GetChild("PaneDisplayP"..i):GetChild("Loading")
-					loadingText:settext("Disabled")
+					loadingText:settext(THEME:GetString("Groovestats", "Disabled"))
 					loadingText:visible(true)
 				end
 			end
@@ -303,7 +303,7 @@ af[#af+1] = RequestResponseActor(17, 50)..{
 				requestCacheKey = requestCacheKey .. SL[pn].Streams.Hash .. SL[pn].ApiKey .. pn
 				local loadingText = master:GetChild("PaneDisplayP"..i):GetChild("Loading")
 				loadingText:visible(true)
-				loadingText:settext("Loading ...")
+				loadingText:settext(THEME:GetString("Groovestats", "Loading"))
 				sendRequest = true
 			end
 		end
@@ -557,7 +557,7 @@ for player in ivalues(PlayerNumber) do
 
 	af2[#af2+1] = LoadFont("Common Normal")..{
 		Name="Loading",
-		Text="Loading ... ",
+		Text=THEME:GetString("Groovestats", "Loading"),
 		InitCommand=function(self)
 			self:zoom(text_zoom):diffuse(Color.Black)
 			self:x(pos.col[3]-15)
@@ -565,7 +565,7 @@ for player in ivalues(PlayerNumber) do
 			self:visible(false)
 		end,
 		SetCommand=function(self)
-			self:settext("Loading ...")
+			self:settext(THEME:GetString("Groovestats", "Loading"))
 			self:visible(false)
 		end
 	}
